package
Version:
v0.0.0-...-c0785da
Opens a new window with list of versions in this module.
Published: Apr 8, 2016
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type InMemoryFile struct {
Name string `json:"name"`
Content string `json:"content"`
}
type Payload struct {
Language string `json:"language"`
Files []*InMemoryFile `json:"files"`
Command string `json:"command"`
}
type Result struct {
Stdout string `json:"stdout"`
Stderr string `json:"stderr"`
Error string `json:"error"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.